Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(471)

Unified Diff: remoting/protocol/jingle_session.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/protocol/jingle_messages_unittest.cc ('k') | remoting/protocol/jingle_session_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/jingle_session.cc
diff --git a/remoting/protocol/jingle_session.cc b/remoting/protocol/jingle_session.cc
index 2277ac043469c9bb922e783cd3a8508db68eb60d..edc48eea6b6649d4de693cab122266516821dc0b 100644
--- a/remoting/protocol/jingle_session.cc
+++ b/remoting/protocol/jingle_session.cc
@@ -71,7 +71,7 @@ ErrorCode AuthRejectionReasonToErrorCode(
JingleSession::JingleSession(JingleSessionManager* session_manager)
: session_manager_(session_manager),
- event_handler_(NULL),
+ event_handler_(nullptr),
state_(INITIALIZING),
error_(OK),
config_is_set_(false),
@@ -342,7 +342,7 @@ void JingleSession::OnMessageResponse(
std::string type_str = JingleMessage::GetActionName(request_type);
// |response| will be NULL if the request timed out.
if (!response) {
LOG(ERROR) << type_str << " request timed out.";
CloseInternal(SIGNALING_TIMEOUT);
@@ -342,7 +342,7 @@ void JingleSession::OnMessageResponse(
std::string type_str = JingleMessage::GetActionName(request_type);
- // |response| will be NULL if the request timed out.
+ // |response| will be nullptr if the request timed out.
if (!response) {
LOG(ERROR) << type_str << " request timed out.";
« no previous file with comments | « remoting/protocol/jingle_messages_unittest.cc ('k') | remoting/protocol/jingle_session_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698